// ASN Filter Designer Professional v4.3.1
// Thu, 17 Oct 2019 21:33:43 GMT

// ** Primary Filter (H1)**

////Band#       Frequencies (Hz)     Att/Ripple (dB)
//    1         0.000,   25.000          0.001
//    2       125.000,  250.000         80.000
////
// Arithmetic = 'Fixed Point (Q0.15)';
// Architecture = 'FIR';
// Structure = 'Direct Form';
// Response = 'Lowpass';
// Method = 'ParksMcClellan';
// GridSize = 100;
// Fs = 500.0000Hz;
// Filter Order = 24


// ** ASN Filter Designer Automatic Code Generator **
// ** Deployment to Arm CMSIS-DSP Framework        **

#include "arm_math.h"

// ** FIR Direct Form Implementation **
// y[n] = b0 * x[n] + b1 * x[n-1] + b2 * x[n-2] + ... + bM * x[n-M]

#define NUMTAPS 26  // Designed Length=25

// FIR coefficients
q15_t firCoeffsq15[NUMTAPS] = 
      {
        0, -14, -37, -16, 	// b[25:22]
        118, 290, 205, -394, 	// b[21:18]
        -1201, -1175, 757, 4506, 	// b[17:14]
        8352, 9990, 8352, 4506, 	// b[13:10]
        757, -1175, -1201, -394, 	// b[9:6]
        205, 290, 118, -16, 	// b[5:2]
        -37, -14	// b[1:0]
      };

			
			
			

// **********************************************************
// Test loop code (Right mouse button -> Show test loop code)
// **********************************************************

									
#define ARM_MATH_CM4   // Cortex-M4 (default). Can be omitted if deploying to CMSIS-DSP v1.7.0 or greater

#define TEST_LENGTH_SAMPLES  128
#define BLOCKSIZE 32
#define NUMBLOCKS  (TEST_LENGTH_SAMPLES/BLOCKSIZE)

float32_t OutputValues[TEST_LENGTH_SAMPLES];
float32_t InputValues[TEST_LENGTH_SAMPLES];
float32_t *InputValuesf32_ptr = &InputValues[0];
float32_t *OutputValuesf32_ptr = &OutputValues[0];
q15_t InputValues_q15[BLOCKSIZE];
q15_t OutputValues_q15[BLOCKSIZE];

q15_t firStatesq15[BLOCKSIZE+NUMTAPS-1];

arm_fir_instance_q15 S;

int32_t main(void)
{

  float32_t SQRT2 = 1.414213;
  uint32_t n,k;

  // setup test sinusoid input
  for (n=0; n<TEST_LENGTH_SAMPLES; n++)
  	InputValues[n]= arm_sin_f32(2*PI*50.00*n/500)/SQRT2;    // test sinusoid input

  // Initialise FIR (Direct Form implementation)
  arm_fir_init_q15 (&S, NUMTAPS, (q15_t*)&(firCoeffsq15[0]), &(firStatesq15[0]), BLOCKSIZE);

  // Perform FIR filtering operation
  for (k=0; k < NUMBLOCKS; k++)
  {
  	arm_float_to_q15 (InputValuesf32_ptr + (k*BLOCKSIZE), InputValues_q15, BLOCKSIZE);    // convert float to q15
  	arm_fir_q15 (&S, InputValues_q15, OutputValues_q15, BLOCKSIZE);    // perform FIR filtering 
  	arm_q15_to_float (OutputValues_q15, OutputValuesf32_ptr + (k*BLOCKSIZE), BLOCKSIZE);  // convert back from q15 to float
  }

  while (1);
}
