// ASN Filter Designer Professional v4.3.1
// Wed, 23 Oct 2019 13:07:52 GMT

// ** Primary Filter (H1)**

////Band#       Frequencies (Hz)     Att/Ripple (dB)
//    1         0.000,   25.000         80.000
//    2       125.000,  250.000          1.500
////
// Arithmetic = 'Floating Point (Single Precision)';
// Architecture = 'IIR';
// Structure = 'Direct Form II Transposed';
// Response = 'HighPass';
// Method = 'Elliptic';
// Biquad = 'Yes';
// Stable = 'Yes';
// Fs = 500.0000; //Hz
// Filter Order = 4;

// ** ASN Filter Designer Automatic Code Generator **
// ** Deployment to Arm CMSIS-DSP Framework        **

#include "arm_math.h"

#define NUM_SECTIONS_IIR 2

// ** IIR Direct Form II Transposed Biquad Implementation **
// y[n] = b0 * x[n] + w1
// w1 = b1 * x[n] + a1 * y[n] + w2
// w2 = b2 * x[n] + a2 * y[n]

// IIR Coefficients
float32_t iirCoeffsf32[NUM_SECTIONS_IIR*5] = 
          {// b0, b1, b2, a1, a2
             0.1361559, -0.2672689,  0.1361559, -0.8183975, -0.3658004, 
             0.3921761, -0.7050342,  0.3921761, -0.0432176, -0.7880579
          };



// **********************************************************
// Test loop code (Right mouse button -> Show test loop code)
// **********************************************************

//#define ARM_MATH_CM4   // Cortex-M4 (default). Can be omitted if deploying to CMSIS-DSP v1.7.0 or greater

#define TEST_LENGTH_SAMPLES  128
#define BLOCKSIZE 32
#define NUMBLOCKS  (TEST_LENGTH_SAMPLES/BLOCKSIZE)

float32_t iirStatesf32[NUM_SECTIONS_IIR*5];

float32_t OutputValues[TEST_LENGTH_SAMPLES];
float32_t InputValues[TEST_LENGTH_SAMPLES];

float32_t *InputValuesf32_ptr = &InputValues[0];  // declare Input pointer 
float32_t *OutputValuesf32_ptr = &OutputValues[0]; // declare Output pointer

arm_biquad_cascade_df2T_instance_f32 S;

int32_t main(void)
{

  uint32_t n,k;

  // setup test sinusoid input
  for (n=0; n<TEST_LENGTH_SAMPLES; n++)
  	InputValues[n]= arm_sin_f32(2*PI*50.0*n/500.0); 

  // Initialise Biquads
  arm_biquad_cascade_df2T_init_f32 (&S, NUM_SECTIONS_IIR, &(iirCoeffsf32[0]), &(iirStatesf32[0]));

  // Perform IIR filtering operation
  for (k=0; k < NUMBLOCKS; k++)
  	arm_biquad_cascade_df2T_f32 (&S, InputValuesf32_ptr + (k*BLOCKSIZE), OutputValuesf32_ptr + (k*BLOCKSIZE), BLOCKSIZE);    // perform filtering 

  while (1);
}
