// ASN Filter Designer Professional v4.3.1
// Wed, 23 Oct 2019 12:54:58 GMT

// ** Primary Filter (H1)**

////Band#       Frequencies (Hz)     Att/Ripple (dB)
//    1         0.000,   25.000         80.000
//    2       125.000,  250.000          1.500
////
// Arithmetic = 'Fixed Point (Q0.15)';
// Architecture = 'IIR';
// Structure = 'Direct Form I';
// Response = 'HighPass';
// Method = 'Elliptic';
// Biquad = 'Yes';
// Stable = 'Yes';
// Fs = 500.0000; //Hz
// Filter Order = 4;

// ** ASN Filter Designer Automatic Code Generator **
// ** Deployment to Arm CMSIS-DSP Framework        **

#include "arm_math.h"

#define NUM_SECTIONS_IIR 2
#define IIR_POST_SCALING 0

// ** IIR Direct Form I Biquad Implementation **
// y[n] = b0 * x[n] + b1 * x[n-1] + b2 * x[n-2] + a1 * y[n-1] + a2 * y[n-2]

// Refer to documentation for details on scaling factors
// IIR Coefficients
q15_t iirCoeffsq15[NUM_SECTIONS_IIR*6] = 
      {// b0, 0, b1, b2, a1, a2
        4462, 0, -8758, 4462, -26817, -11987, 
        12851, 0, -23103, 12851, -1416, -25823
      };



// **********************************************************
// Test loop code (Right mouse button -> Show test loop code)
// **********************************************************

#define ARM_MATH_CM4   // Cortex-M4 (default). Can be omitted if deploying to CMSIS-DSP v1.7.0 or greater

#define TEST_LENGTH_SAMPLES  128
#define BLOCKSIZE 32
#define NUMBLOCKS  (TEST_LENGTH_SAMPLES/BLOCKSIZE)

q15_t iirStatesq15[NUM_SECTIONS_IIR*6];

float32_t OutputValues[TEST_LENGTH_SAMPLES];
float32_t InputValues[TEST_LENGTH_SAMPLES];

float32_t *InputValuesf32_ptr = &InputValues[0];  // declare Input pointer 
float32_t *OutputValuesf32_ptr = &OutputValues[0]; // declare Output pointer

q15_t InputValues_q15[BLOCKSIZE];
q15_t OutputValues_q15[BLOCKSIZE];

arm_biquad_casd_df1_inst_q15 S;

int32_t main(void)
{

  float32_t SQRT2 = 1.414213;
  uint32_t n,k;

  // setup test sinusoid input
  for (n=0; n<TEST_LENGTH_SAMPLES; n++)
  	InputValues[n]= arm_sin_f32(2*PI*50.00*n/500.0)/SQRT2;

  // Initialise Biquads
  arm_biquad_cascade_df1_init_q15 (&S, NUM_SECTIONS_IIR, &(iirCoeffsq15[0]), &(iirStatesq15[0]),IIR_POST_SCALING);

  // Perform IIR filtering operation
  for (k=0; k < NUMBLOCKS; k++)
  {
  	arm_float_to_q15 (InputValuesf32_ptr + (k*BLOCKSIZE), InputValues_q15, BLOCKSIZE);    // convert float to q15
  	arm_biquad_cascade_df1_q15 (&S, InputValues_q15, OutputValues_q15, BLOCKSIZE);    // perform filtering 
  	arm_q15_to_float (OutputValues_q15, OutputValuesf32_ptr + (k*BLOCKSIZE), BLOCKSIZE);  // convert back from q15 to float
  }

  while (1);
}
